@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2018 Osimis S.A., Belgium
+ * Copyright (C) 2017-2019 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -88,7 +88,8 @@ namespace OrthancWSI
                                   unsigned int tileX,
                                   unsigned int tileY);
 
-    Orthanc::ImageAccessor GetDecodedTile(unsigned int tileX,
-                                          unsigned int tileY);  
+    void GetDecodedTile(Orthanc::ImageAccessor& target,
+                        unsigned int tileX,
+                        unsigned int tileY);  
   };
 }
