@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2018 Osimis S.A., Belgium
+ * Copyright (C) 2017-2019 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -33,9 +33,7 @@ namespace OrthancWSI
     Jpeg2000Format_Unknown
   };
 
-  class Jpeg2000Reader : 
-    public Orthanc::ImageAccessor,
-    public boost::noncopyable
+  class Jpeg2000Reader : public Orthanc::ImageAccessor
   {
   private:
     std::auto_ptr<Orthanc::ImageAccessor> image_;
