@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2018 Osimis S.A., Belgium
+ * Copyright (C) 2017-2019 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -117,7 +117,9 @@ namespace OrthancWSI
       Tiles::const_iterator it = tiles_.find(std::make_pair(tileX, tileY));
       if (it != tiles_.end())
       {
-        return new Orthanc::ImageAccessor(*it->second);
+        std::auto_ptr<Orthanc::ImageAccessor> result(new Orthanc::ImageAccessor);
+        it->second->GetReadOnlyAccessor(*result);
+        return result.release();
       }
       else
       {
